@@ -163,8 +163,10 @@ impl<T> WastContext<T> {
             .get_export(instance_name, field)?
             .into_func()
             .ok_or_else(|| anyhow!("no function named `{}`", field))?;
-        Ok(match func.call(&mut self.store, args) {
-            Ok(result) => Outcome::Ok(result.into()),
+
+        let mut results = vec![Val::null(); func.ty(&self.store).results().len()];
+        Ok(match func.call(&mut self.store, args, &mut results) {
+            Ok(()) => Outcome::Ok(results.into()),
             Err(e) => Outcome::Trap(e.downcast()?),
         })
     }
@@ -200,10 +202,6 @@ impl<T> WastContext<T> {
         {
             return Ok(());
         }
-        if cfg!(feature = "lightbeam") {
-            println!("TODO: Check the assert_trap message: {}", expected);
-            return Ok(());
-        }
         bail!("expected '{}', got '{}'", expected, actual)
     }
 
@@ -351,7 +349,7 @@ impl<T> WastContext<T> {
                     )
                 }
             }
-            AssertUncaughtException { .. } => bail!("unimplemented assert_uncaught_exception"),
+            AssertException { .. } => bail!("unimplemented assert_exception"),
         }
 
         Ok(())
